@@ -20,7 +20,7 @@ sub unescape {
     s{
 	( \\ x\{[0-9a-f]+\}
 	| \\ x[0-9a-f]{2}
-	| \\ N\{[\ \w]+\}
+	| \\ N\{[\-\ \w]+\}
 	| \\ N\{U\+[0-9a-f]+\}
 	| \\ c.
 	| \\ o\{\d+\}
